Error

Enum Error 

#[non_exhaustive]
pub enum Error { XmlParse(String), NotTtmlRoot(String), MissingElement(&'static str), MissingAttribute { element: &'static str, attr: &'static str, }, InvalidAttribute { element: &'static str, attr: &'static str, reason: String, }, InvalidTimeExpression { value: String, reason: String, }, Validation(String), UnexpectedElement { name: String, ns: String, }, ProhibitedElement { name: String, }, ProhibitedAttribute { attr: String, }, ConstraintViolation { constraint: String, detail: String, }, Serialize(String), }
Errors that can occur during TTML/IMSC processing.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


XmlParse(String)

XML parsing failed (syntax error, not well-formed).



NotTtmlRoot(String)

The root element is not <tt> in the TTML namespace.



MissingElement(&'static str)

A required element is missing.



MissingAttribute

A required attribute is missing.

Fields

element: &'static str

The element name.

attr: &'static str

The attribute name.



InvalidAttribute

A required attribute value is malformed.

Fields

element: &'static str

The element name.

attr: &'static str

The attribute name.

reason: String

Why the value is invalid.



InvalidTimeExpression

A time-expression could not be parsed.

Fields

value: String

The raw time expression text.

reason: String

Why it’s invalid.



Validation(String)

IMSC profile validation failed.



UnexpectedElement

An unexpected element was found in a location where it is not valid.

Fields

name: String

The element local name.

ns: String

The element namespace, if any.



ProhibitedElement

An element was found that is prohibited by the content profile.

Fields

name: String

The element name.



ProhibitedAttribute

An attribute was found that is prohibited by the content profile.

Fields

attr: String

The attribute name.



ConstraintViolation

A generic constraint violation.

Fields

constraint: String

The constraint that was violated.

detail: String

Additional detail.



Serialize(String)

Serialization error.